@@ -3,8 +3,6 @@ from typing import Optional, Type
 import configargparse
 from pydantic import BaseModel, Extra
 
-SIMPLE_TYPES = [bool, str, int, float, list, dict, tuple]
-
 
 class Config(BaseModel, extra=Extra.forbid):
     """ Config class for G3ConfigMeta metaclass."""
@@ -16,6 +14,9 @@ class Config(BaseModel, extra=Extra.forbid):
     """ Specify it to automatically enable getting of all your class variables from environment variables.
     This prefix is used only if you didn't specify `env_var` parameter in `Param`."""
 
+    auto_replace_underscores_with_dashes: bool = True
+    """ Automatically replace underscores with dashes in CLI argument names."""
+
 
 class ArgParserConfig(BaseModel, extra=Extra.allow):
     """ ArgParserConfig class that directly process almost all it's fields
